import { AmplifyIOHost, BackendIdentifier, PackageManagerController, SDKProfileResolver } from '@aws-amplify/plugin-types';
import { BackendDeployerOutputFormatter } from './types.js';
export type DeployProps = {
    secretLastUpdated?: Date;
    validateAppSources?: boolean;
};
export type DeployResult = {
    deploymentTimes: DeploymentTimes;
};
export type DestroyResult = {
    deploymentTimes: DeploymentTimes;
};
export type DeploymentTimes = {
    synthesisTime?: number;
    totalTime?: number;
};
/**
 * Invokes an invokable command
 */
export type BackendDeployer = {
    deploy: (backendId: BackendIdentifier, deployProps?: DeployProps) => Promise<DeployResult>;
    destroy: (backendId: BackendIdentifier) => Promise<DestroyResult>;
};
/**
 * Factory to create a backend deployer
 */
export declare class BackendDeployerFactory {
    private readonly packageManagerController;
    private readonly formatter;
    private readonly backendDeployerIOHost;
    private readonly sdkProfileResolver;
    private static instance;
    /**
     * constructor - sets the packageManagerController
     */
    constructor(packageManagerController: PackageManagerController, formatter: BackendDeployerOutputFormatter, backendDeployerIOHost: AmplifyIOHost, sdkProfileResolver: SDKProfileResolver);
    /**
     * Returns a single instance of BackendDeployer
     */
    getInstance(): BackendDeployer;
}
//# sourceMappingURL=cdk_deployer_singleton_factory.d.ts.map